@@ -135,6 +135,8 @@ impl<T> Drop for Buffer<T> {
     }
 }
 
+unsafe impl<T: Send> Send for Buffer<T> {}
+
 impl<T> Buffer<T> {
     pub fn new(buffer: cl_mem) -> Buffer<T> {
         Buffer {
@@ -287,6 +289,8 @@ impl Drop for Image {
     }
 }
 
+unsafe impl Send for Image {}
+
 impl Image {
     pub fn new(image: cl_mem) -> Image {
         Image { image }
@@ -663,6 +667,8 @@ impl Drop for Sampler {
     }
 }
 
+unsafe impl Send for Sampler {}
+
 impl Sampler {
     pub fn new(sampler: cl_sampler) -> Sampler {
         Sampler { sampler }
